# Segmenting your images

## Opening the sample image
<div style="text-align: center;">
    <video controls autoplay muted width="640" height="360" preload="metadata">
    <source src="../open-sample.mp4" type="video/mp4">
    Your browser does not support the video tag.
    </video>
</div>

## Segmentation
<div style="text-align: center;">
    <video controls autoplay muted width="640" height="360" preload="metadata">
    <source src="../segmentation-sample.mp4" type="video/mp4">
    Your browser does not support the video tag.
    </video>
</div>

## Applying filters to the image mask
<div style="text-align: center;">
    <video controls autoplay muted width="640" height="360" preload="metadata">
    <source src="../mask-processing-sample.mp4" type="video/mp4">
    Your browser does not support the video tag.
    </video>
</div>